<?php

namespace SGalinski\SgJobs\Controller;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use SGalinski\SgJobs\Service\BackendService;
use TYPO3\CMS\Backend\Template\Components\DocHeaderComponent;
use TYPO3\CMS\Backend\Utility\BackendUtility;
use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Core\Utility\VersionNumberUtility;
use TYPO3\CMS\Extbase\Mvc\Controller\ActionController;

/**
 * The backend module controller
 */
class BackendController extends ActionController {
	/**
	 * DocHeaderComponent
	 *
	 * @var DocHeaderComponent
	 */
	protected $docHeaderComponent;

	/**
	 * The uid of the current root page
	 *
	 * @var int
	 */
	private $rootPageUid = 0;

	/**
	 * Show all job offers and options to manage them
	 *
	 * @param array $filters
	 * @return void
	 */
	public function indexAction(array $filters = []) {
		// create doc header component
		try {
			$pageUid = (int) GeneralUtility::_GP('id');

			if ($pageUid) {
				$this->rootPageUid = BackendService::getRootUidByPageUid($pageUid);
			}

			// create docheader + buttons
			$pageInfo = BackendUtility::readPageAccess($pageUid, $GLOBALS['BE_USER']->getPagePermsClause(1));
			$this->docHeaderComponent = GeneralUtility::makeInstance(DocHeaderComponent::class);
			$this->docHeaderComponent->setMetaInformation($pageInfo);
			BackendService::makeButtons($this->docHeaderComponent, $this->request);

			// if we are not on a root page, display the root pages to the user
			if (!$this->rootPageUid) {
				$this->view->assign('rootOptions', BackendService::getRootOptions());
			}

			$this->view->assign('pageUid', $pageUid);
			$this->view->assign('rootPageUid', $this->rootPageUid);
			$this->view->assign('docHeader', $this->docHeaderComponent->docHeaderContent());
			$this->view->assign('typo3Version', VersionNumberUtility::convertVersionNumberToInteger(TYPO3_version));
			$this->view->assign('docHeader', $this->docHeaderComponent->docHeaderContent());
		} catch (\Exception $exception) {
			// check for NULL value in view and render an error message
			$this->view->assign('docHeader', NULL);
		}

	}
}
